==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DochodSwiadczenieSkladnikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DochodSwiadczenieSkladnikKey extends GenericDPSObject {
    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.DOCHOD_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dochodId;

    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DOCHOD_SWIADCZENIE_SKLADNIK.DOCHOD_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDochodId() {
        return dochodId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:41
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.DOCHOD_ID
     *
     * @param dochodId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDochodId(Long dochodId) {
        this.dochodId = dochodId;
    }

    /**
     * @return DOCHOD_SWIADCZENIE_SKLADNIK.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DochodSwiadczenieSkladnikKey other = (DochodSwiadczenieSkladnikKey) that;
        return (this.getDochodId() == null ? other.getDochodId() == null : this.getDochodId().equals(other.getDochodId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDochodId() == null) ? 0 : getDochodId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", dochodId=").append(dochodId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DochodSwiadczenieSkladnikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DochodSwiadczenieSkladnikKey extends GenericDPSObject {
    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.DOCHOD_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dochodId;

    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DOCHOD_SWIADCZENIE_SKLADNIK.DOCHOD_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDochodId() {
        return dochodId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:45
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.DOCHOD_ID
     *
     * @param dochodId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDochodId(Long dochodId) {
        this.dochodId = dochodId;
    }

    /**
     * @return DOCHOD_SWIADCZENIE_SKLADNIK.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * DOCHOD_SWIADCZENIE_SKLADNIK.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DochodSwiadczenieSkladnikKey other = (DochodSwiadczenieSkladnikKey) that;
        return (this.getDochodId() == null ? other.getDochodId() == null : this.getDochodId().equals(other.getDochodId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDochodId() == null) ? 0 : getDochodId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", dochodId=").append(dochodId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}
